==> tencentcloud-sdk-java-3.1.87-sources.jar: com/tencentcloudapi/cdn/v20180606/models/DescribeCertDomainsRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cdn.v20180606.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeCertDomainsRequest extends AbstractModel{

    /**
    * PEM格式证书Base64编码后的字符串
    */
    @SerializedName("Cert")
    @Expose
    private String Cert;

    /**
     * Get PEM格式证书Base64编码后的字符串 
     * @return Cert PEM格式证书Base64编码后的字符串
     */
    public String getCert() {
        return this.Cert;
    }

    /**
     * Set PEM格式证书Base64编码后的字符串
     * @param Cert PEM格式证书Base64编码后的字符串
     */
    public void setCert(String Cert) {
        this.Cert = Cert;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Cert", this.Cert);

    }
}

==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/cdn/v20180606/models/DescribeCertDomainsRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cdn.v20180606.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeCertDomainsRequest extends AbstractModel{

    /**
    * PEM格式证书Base64编码后的字符串
    */
    @SerializedName("Cert")
    @Expose
    private String Cert;

    /**
     * Get PEM格式证书Base64编码后的字符串 
     * @return Cert PEM格式证书Base64编码后的字符串
     */
    public String getCert() {
        return this.Cert;
    }

    /**
     * Set PEM格式证书Base64编码后的字符串
     * @param Cert PEM格式证书Base64编码后的字符串
     */
    public void setCert(String Cert) {
        this.Cert = Cert;
    }

    public DescribeCertDomainsRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeCertDomainsRequest(DescribeCertDomainsRequest source) {
        if (source.Cert != null) {
            this.Cert = new String(source.Cert);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Cert", this.Cert);

    }
}
